AIDataSimpleFilter - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# AIDataSimpleFilter

class inmydata.StructuredData.AIDataSimpleFilter(Field: str, Value)

  Bases: `object`

  A class representing a simple filter for querying data in the inmydata platform. This class encapsulates the details of a simple filter, including the field to filter on and the value to filter by.

  Field

    The field to filter on.

    Type:

      str

  Value

    The value to filter by.

  ## Members

  __init__(Field: str, Value)

    Initializes the AIDataSimpleFilter with the specified field and value.

    Parameters:

      - Field (str) – The field to filter on.

      - Value – The value to filter by.

  to_dict()

    Converts the AIDataSimpleFilter instance to a dictionary representation.

    Returns:

      A dictionary representation of the AIDataSimpleFilter instance.

    Return type:

      dict